/*
** Module   : NativeInt8.java
** Abstract : descriptor for a unsigned or signed byte 
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 GES 20140109 First version, which defaults to being an unsigned byte.
*/

package com.goldencode.p2j.library;

import java.io.*;
import com.goldencode.p2j.util.*;

/**
 * A descriptor for a byte which may be either signed or unsigned. The 4GL does not differentiate
 * between the two types, but the native code may be sensitive to this.  If this instance must
 * represent signed data, then the type should be explicitly changed (using 
 * {@link BaseNativeType#setType}) to {@link LibraryManager#TYPE_SIGNED_INT8}. By default, the
 * type is set to {@link LibraryManager#TYPE_UNSIGNED_INT8}.
 */
public class NativeInt8 
extends NativeInteger
{
   /**
    * Default constructor.
    */
   public NativeInt8()
   {
      super();
      
      // default to unsigned and override later if needed 
      type = LibraryManager.TYPE_UNSIGNED_INT8;
   }
   
   /**
    * Report the size (in bytes) of the native memory needed to store this instance.
    * <p>
    * This should never be called on the server, only on the client side.
    *
    * @return   The number of bytes needed.
    */
   public int size()
   {
      return 1;
   }
   
   /**
    * Worker method to read the primitive value from the first index position of the given
    * memory buffer.
    *
    * @param    ptr
    *           The memory buffer to reference.
    */
   protected void readNative(memptr ptr)
   {
      integer num = ptr.getByte(1);
      
      if (!num.isUnknown())
      {
         value = num.longValue();
      }
   }
   
   /**
    * Worker method to write the primitive value to the first index position of the given
    * memory buffer.
    *
    * @param    ptr
    *           The memory buffer to reference.
    */
   protected void writeNative(memptr ptr)
   {
      ptr.setByte(value, 1);
   }
}
